@@ -59,6 +59,7 @@ typedef int32_t glsi32;
 #define GLK_MODULE_RESOURCE_STREAM
 
 #define GLK_MODULE_GARGLKTEXT
+#define GLK_MODULE_GARGLKBLEEP
 #define GLK_MODULE_FILEREF_GET_NAME
 
 /* Define a macro for a function attribute that indicates a function that
@@ -313,7 +314,7 @@ extern glui32 glk_fileref_does_file_exist(frefid_t fref);
 extern void glk_select(event_t *event);
 extern void glk_select_poll(event_t *event);
 
-extern void glk_request_timer_events(glui32 millisecs);
+extern void glk_request_timer_events(glui32 ms);
 
 extern void glk_request_line_event(winid_t win, char *buf, glui32 maxlen,
     glui32 initlen);
@@ -480,6 +481,9 @@ extern strid_t glk_stream_open_resource_uni(glui32 filenum, glui32 rock);
 
 #define GARGLK 1
 
+#ifdef __GNUC__
+__attribute__((__deprecated__("Use glkunix_fileref_get_filename instead")))
+#endif
 extern const char *garglk_fileref_get_name(frefid_t fref);
 
 extern void garglk_set_program_name(const char *name);
@@ -506,6 +510,8 @@ extern void garglk_set_zcolors_stream(strid_t str, glui32 fg, glui32 bg);
 extern void garglk_set_reversevideo(glui32 reverse);
 extern void garglk_set_reversevideo_stream(strid_t str, glui32 reverse);
 
+extern void garglk_zbleep(glui32 number);
+
 /* non standard keycodes */
 #define keycode_Erase               (0xffffef7f)
 #define keycode_MouseWheelUp        (0xffffeffe)
